/* usbmsgd: Usb mass storage gadget daemon to access usb storage
 * Copyright (C) 2018 Robert Bosch Power Tools GmbH
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * Author: Vinay Kumar Shettar <vinaykumar.shettar@in.bosch.com>
 */
/**
 * @file usbmsgd.h
 * @brief header file of usbmsgd.
 *
 * @copydoc Usbmsgd
 */

#ifndef USBMSGD_H
#define USBMSGD_H
#pragma once

#include <usbmsgd-generated.h>

#define SUCCESS 0
#define FAILED 1

#define USBMSGD_BACKING_FILE "/var/lib/mass_storage"

#define USBMSGD_MOUNT_DIR "/media/storage"

/**
 * @brief usbmsgd function declarations.
 * Detailed description.
 * Concept Based on GDBus IPC (Property, Methods, Signal)
 * For Reference
 * https://developer.gnome.org/gio/stable/gdbus-convenience.html
 * For Example
 * https://developer.gnome.org/gio/stable/gdbus-codegen.html
 */

typedef enum {
        USBMSGD_FORMAT_STATE_UNKNOWN = 0,
        USBMSGD_FORMAT_STARTED,
        USBMSGD_FORMAT_DONE = 100,
        USBMSGD_FORMAT_FAILED = 200
} UsbmsgdFormatStatus;

typedef struct
{
  /* D-Bus server object for setting the status and result values */
  ComBosch_ptUsbmsgd *usbmsgd_object;
  GMainLoop *loop;
  gchar *device_name;
} USBMSG;

void usbmsgd_bus_acquired (GDBusConnection *connection, const gchar *name,
                           gpointer user_data);
void usbmsgd_name_acquired (GDBusConnection *connection, const gchar *name,
                            gpointer user_data);
void usbmsgd_name_lost (GDBusConnection *connection, const gchar *name,
                        gpointer user_data);
void usbmsgd_init (USBMSG *usbmsg);
void usbmsgd_deinit (USBMSG *usbmsg);

#endif /* USBMSGD_H */
